.. NuRadioReco documentation master file, created by
   sphinx-quickstart on Wed Sep  4 14:13:16 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to NuRadioReco's documentation!
=======================================

.. toctree::
   :maxdepth: 1

   pages/introduction
   pages/event_structure
   pages/detector
   pages/nur_modules
   pages/event_display
   pages/utilities
   pages/contributing
   pages/code_documentation
   pages/detector_database_fields.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
